@@ -92,6 +92,9 @@ FAILEDOPERATION_DOMAINALREADYBINDOTHERSERVICE = 'FailedOperation.DomainAlreadyBi
 # 该域名已经绑定该服务。
 FAILEDOPERATION_DOMAINALREADYBINDSERVICE = 'FailedOperation.DomainAlreadyBindService'
 
+# 当前域名不满足合规要求，无法进行接入。
+FAILEDOPERATION_DOMAININBLACKLIST = 'FailedOperation.DomainInBlackList'
+
 # 该域名还未在腾讯云备案，请备案之后再绑定域名。
 FAILEDOPERATION_DOMAINNEEDBEIAN = 'FailedOperation.DomainNeedBeian'
 
@@ -155,6 +158,9 @@ INTERNALERROR = 'InternalError'
 # API网关内部请求错误，请稍后重试。若无法解决，请联系智能客服或提交工单。
 INTERNALERROR_APIGWEXCEPTION = 'InternalError.ApigwException'
 
+# CAuth内部请求错误，请稍后重试。若无法解决，请联系智能客服或提交工单。
+INTERNALERROR_CAUTHEXCEPTION = 'InternalError.CauthException'
+
 # oss内部请求错误，请稍后重试。若无法解决，请联系智能客服或提交工单。
 INTERNALERROR_OSSEXCEPTION = 'InternalError.OssException'
 
